systems.thoughtfull.assay.baseline.core


changed-bricksclj

(changed-bricks measurements changed-files)

compare-reportsclj

(compare-reports base head changed-files {:keys [changes new-dependencies]})

evaluate-changecljmultimethod

Evaluate a change rule against a brick's base value (nil for a new brick) and head value. Returns nil if the rule passes, or a map of :limit and :message.

Evaluate a change rule against a brick's base value (nil for a new brick)
and head value. Returns nil if the rule passes, or a map of :limit and
:message.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries