systems.thoughtfull.assay.dependencies.cohesion

Cohesion within bricks, from the symbols each definition references.

  • Cohesion: references to the brick's own namespaces / references to any workspace namespace. References to other libraries don't count.
Cohesion within bricks, from the symbols each definition references.

- Cohesion: references to the brick's own namespaces / references to any
  workspace namespace. References to other libraries don't count.
raw docstring

analyzeclj

(analyze {:keys [top-namespace]} measurements)

Cohesion for each brick, by name, and :used, the set of [segment name] interface definitions other bricks refer to.

Cohesion for each brick, by name, and :used, the set of [segment name]
interface definitions other bricks refer to.
raw docstring

referencesclj

(references source)

Every resolved reference in a source: maps of :from ([ns name] of the referring definition), :ns, and :name.

Every resolved reference in a source: maps of :from ([ns name] of the
referring definition), :ns, and :name.
raw docstring

resolverclj

(resolver {:keys [ns requires definitions]})

A function from a symbol referenced in source to [namespace name], or nil if it doesn't refer to a definition in a known namespace.

A function from a symbol referenced in source to [namespace name], or
nil if it doesn't refer to a definition in a known namespace.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries