Clojure only.

systems.thoughtfull.assay.dependencies.errors

Error surface: the interface definitions of each component that can throw. A definition throws if its body contains throw, or refers to a definition that throws, in its own brick or another. Catching isn't taken into account, so this is an upper bound.

Error surface: the interface definitions of each component that can
throw. A definition throws if its body contains throw, or refers to a
definition that throws, in its own brick or another. Catching isn't
taken into account, so this is an upper bound.
raw docstring

analyzeclj

(analyze {:keys [top-namespace] :as workspace} measurements)

Brick name to {:error-surface r :throwing-interface n :interface-definitions n}: the share and number of the component's public interface definitions that can throw, and how many it has. A base has none of them, and a component without public interface definitions no :error-surface.

Brick name to {:error-surface r :throwing-interface n
:interface-definitions n}: the share and number of the component's
public interface definitions that can throw, and how many it has. A
base has none of them, and a component without public interface
definitions no :error-surface.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries