Map namespaces to Polylith interfaces.
Map namespaces to Polylith interfaces.
(interface-ns? {:keys [top-namespace interface-ns]} brick-segment ns)True if ns is the interface namespace of brick-segment, or one of its sub-interfaces.
True if ns is the interface namespace of brick-segment, or one of its sub-interfaces.
(own-segment top-ns {:keys [sources]})The segment of most of a brick's namespaces: its interface name, for a component.
The segment of most of a brick's namespaces: its interface name, for a component.
(segment top-ns ns)The first namespace segment after top-ns, or nil if ns is not in the workspace.
The first namespace segment after top-ns, or nil if ns is not in the workspace.
(segments top-ns measurements)Brick name to its own segment, for every measurement.
Brick name to its own segment, for every measurement.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |