systems.thoughtfull.assay.git.interface

Read revisions and changes from the Git repository containing a workspace.

Read revisions and changes from the Git repository containing a
workspace.
raw docstring

changed-filesclj

(changed-files root rev)

Paths, relative to root, of files under root that differ between rev and the working tree, including untracked files that are not ignored.

Paths, relative to root, of files under root that differ between rev and
the working tree, including untracked files that are not ignored.
raw docstring

extractclj

(extract root rev dir)

Write the tree of rev under root (which may be a subdirectory of the repository) into the existing directory dir.

Write the tree of rev under root (which may be a subdirectory of the
repository) into the existing directory dir.
raw docstring

merge-baseclj

(merge-base root ref)

The commit where HEAD diverged from ref, as a full SHA.

The commit where HEAD diverged from ref, as a full SHA.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries