systems.thoughtfull.assay.thresholds.core


checkclj

(check {:keys [brick-thresholds function-thresholds]} measurements)

default-configclj


evaluatecljmultimethod

Evaluate rule against a brick's value and its peers' values. Returns nil if the rule passes, or a map of :limit, :message, and optionally :stats.

Evaluate rule against a brick's value and its peers' values. Returns nil
if the rule passes, or a map of :limit, :message, and optionally :stats.
raw docstring

merge-configclj

(merge-config config)

worse-levelclj

(worse-level a b)

cljdoc builds & hosts documentation for Clojure/Script libraries