Clojure only.

systems.thoughtfull.assay.workspace.interface

Discover the bricks of a Polylith workspace.

Discover the bricks of a Polylith workspace.
raw docstring

bricksclj

(bricks root)

The bricks (components and bases) of the Polylith workspace at root, sorted by type then name. Each is a map of :name, :type (:component or :base), :dir (relative to root), :files, the brick's Clojure source files under src, and :test-files, those under test, all relative to root.

The bricks (components and bases) of the Polylith workspace at root, sorted
by type then name. Each is a map of :name, :type (:component or :base),
:dir (relative to root), :files, the brick's Clojure source files under
src, and :test-files, those under test, all relative to root.
raw docstring

configclj

(config root)

The Polylith settings of the workspace at root that assay uses, from workspace.edn: :top-namespace (a string, or nil) and :interface-ns (default "interface").

The Polylith settings of the workspace at root that assay uses, from
workspace.edn: :top-namespace (a string, or nil) and :interface-ns
(default "interface").
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries