(changed-bricks measurements changed-files)(compare-reports base head changed-files {:keys [changes new-dependencies]})Evaluate a change rule against a brick's base value (nil for a new brick) and head value. Returns nil if the rule passes, or a map of :limit and :message.
Evaluate a change rule against a brick's base value (nil for a new brick) and head value. Returns nil if the rule passes, or a map of :limit and :message.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |