Command line entry point. Measures every brick of a Polylith workspace, checks the measurements against thresholds, optionally compares them with a base revision, and writes an HTML report or a GitHub Actions report.
Command line entry point. Measures every brick of a Polylith workspace, checks the measurements against thresholds, optionally compares them with a base revision, and writes an HTML report or a GitHub Actions report.
(-main & args)(report workspace-dir config base-ref)Measure the workspace at workspace-dir and check it against config, comparing with the merge-base of base-ref when it is given. Returns a report map for the report components.
Measure the workspace at workspace-dir and check it against config, comparing with the merge-base of base-ref when it is given. Returns a report map for the report components.
(run args env)Run with command line args and environment env (a map of variable name to value). Prints output and returns the exit status.
Run with command line args and environment env (a map of variable name to value). Prints output and returns the exit status.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |