Clojure only.

systems.thoughtfull.assay.dependencies.errors

Error surface: the interface definitions of each component that can throw. A definition throws if its body contains throw, or refers to a definition that throws, in its own brick or another. Catching isn't taken into account, so this is an upper bound.

Error surface: the interface definitions of each component that can
throw. A definition throws if its body contains throw, or refers to a
definition that throws, in its own brick or another. Catching isn't
taken into account, so this is an upper bound.
raw docstring

analyzeclj

(analyze {:keys [top-namespace] :as workspace} measurements)

Brick name to {:error-surface n}: the component's interface definitions that can throw, or nil for a base.

Brick name to {:error-surface n}: the component's interface definitions
that can throw, or nil for a base.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries