Library spread: the bricks that require each library outside the workspace. A library wrapped by one brick can be replaced or upgraded in one place; one spread across bricks, such as a database driver, means a missing gateway component.
Library spread: the bricks that require each library outside the workspace. A library wrapped by one brick can be replaced or upgraded in one place; one spread across bricks, such as a database driver, means a missing gateway component.
(analyze top-ns measurements)The libraries outside the workspace that each brick requires, as :libraries, a vector of {:library :bricks :requires} with :requires the first require of the library in each brick ({:brick :file :line}), most spread first; and :metrics, brick name to :libraries and :shared-libraries counts.
The libraries outside the workspace that each brick requires, as
:libraries, a vector of {:library :bricks :requires} with :requires the
first require of the library in each brick ({:brick :file :line}), most
spread first; and :metrics, brick name to :libraries and
:shared-libraries counts.(violations {:keys [max-bricks level]} {:keys [bricks libraries]})A violation at each brick's require of a library that more than max-bricks bricks require.
A violation at each brick's require of a library that more than max-bricks bricks require.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |