systems.thoughtfull.assay.dependencies.names

Map namespaces to Polylith interfaces.

Map namespaces to Polylith interfaces.
raw docstring

interface-ns?clj

(interface-ns? {:keys [top-namespace interface-ns]} brick-segment ns)

True if ns is the interface namespace of brick-segment, or one of its sub-interfaces.

True if ns is the interface namespace of brick-segment, or one of its
sub-interfaces.
raw docstring

own-segmentclj

(own-segment top-ns {:keys [sources]})

The segment of most of a brick's namespaces: its interface name, for a component.

The segment of most of a brick's namespaces: its interface name, for a
component.
raw docstring

segmentclj

(segment top-ns ns)

The first namespace segment after top-ns, or nil if ns is not in the workspace.

The first namespace segment after top-ns, or nil if ns is not in the
workspace.
raw docstring

segmentsclj

(segments top-ns measurements)

Brick name to its own segment, for every measurement.

Brick name to its own segment, for every measurement.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries