Render a report for GitHub Actions: workflow command annotations and a Markdown job summary.
A report is a map of :workspace (a name), :bricks (measurements from the metrics component), and :violations (from the thresholds component).
Render a report for GitHub Actions: workflow command annotations and a Markdown job summary. A report is a map of :workspace (a name), :bricks (measurements from the metrics component), and :violations (from the thresholds component).
(annotations report)Workflow commands (::error and ::warning lines) for each violation. Print them to stdout in a workflow step.
Workflow commands (::error and ::warning lines) for each violation. Print them to stdout in a workflow step.
(summary report)Markdown for the job summary. Append it to the file named by the GITHUB_STEP_SUMMARY environment variable.
Markdown for the job summary. Append it to the file named by the GITHUB_STEP_SUMMARY environment variable.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |