systems.thoughtfull.assay.metrics.core


column-textclj

(column-text {:keys [keys]} metrics)

columnsclj


format-valueclj

(format-value k v)

fragment-min-formsclj

The fewest forms in a fragment kept for duplicate detection.

The fewest forms in a fragment kept for duplicate detection.
raw docstring

function-idclj

(function-id {:keys [ns name]})

function-metricsclj


labelclj

(label {:keys [scope metric label]})

measure-brickclj

(measure-brick root brick)

measure-sourceclj

(measure-source file source)

metricsclj


notable-functionsclj

(notable-functions measurements flagged? n)

totalsclj

(totals measurements)

cljdoc builds & hosts documentation for Clojure/Script libraries