Render a report as plain text for a terminal, such as a Git hook.
A report is a map of :bricks (measurements from the metrics component), :violations (from the thresholds component), and, when compared with a base, :comparison (from the baseline component).
Render a report as plain text for a terminal, such as a Git hook. A report is a map of :bricks (measurements from the metrics component), :violations (from the thresholds component), and, when compared with a base, :comparison (from the baseline component).
(render report)One line per violation, then a summary line. When the report has a comparison, only violations that a change introduced are listed.
One line per violation, then a summary line. When the report has a comparison, only violations that a change introduced are listed.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |