Compare brick and function measurements to threshold rules.
Configuration has two maps from metric key to a vector of rules: :brick-thresholds for brick metrics and :function-thresholds for each function's metrics. Each rule is a map with a :rule type, a :value, and an optional :level (:error, the default, or :warning):
Brick rules take an optional :types, a set of brick types (:component, :base) the rule applies to. Rules skip metrics with no value.
Compare brick and function measurements to threshold rules.
Configuration has two maps from metric key to a vector of rules:
:brick-thresholds for brick metrics and :function-thresholds for each
function's metrics. Each rule is a map with a :rule type, a :value, and an
optional :level (:error, the default, or :warning):
- {:rule :max :value n} flags a value above n.
- {:rule :min :value n} flags a value below n.
- {:rule :std-devs :value k} flags a brick whose metric is more than k
standard deviations above the mean of the other bricks of the same type
(components are compared with components, bases with bases). It needs
at least :min-peers other bricks (default 3) and is skipped otherwise.
Brick thresholds only.
Brick rules take an optional :types, a set of brick types (:component,
:base) the rule applies to. Rules skip metrics with no value.cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |