(check {:keys [brick-thresholds function-thresholds]} measurements)Evaluate rule against a brick's value and its peers' values. Returns nil if the rule passes, or a map of :limit, :message, and optionally :stats.
Evaluate rule against a brick's value and its peers' values. Returns nil if the rule passes, or a map of :limit, :message, and optionally :stats.
(merge-config config)(worse-level a b)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |