Discover the bricks of a Polylith workspace.
Discover the bricks of a Polylith workspace.
(bricks root)The bricks (components and bases) of the Polylith workspace at root, sorted by type then name. Each is a map of :name, :type (:component or :base), :dir (relative to root), and :files, the brick's Clojure source files under src, relative to root.
The bricks (components and bases) of the Polylith workspace at root, sorted by type then name. Each is a map of :name, :type (:component or :base), :dir (relative to root), and :files, the brick's Clojure source files under src, relative to root.
(config root)The Polylith settings of the workspace at root that assay uses, from workspace.edn: :top-namespace (a string, or nil) and :interface-ns (default "interface").
The Polylith settings of the workspace at root that assay uses, from workspace.edn: :top-namespace (a string, or nil) and :interface-ns (default "interface").
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |